import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
const { getPaletteColor, getAppColor } = ColorUtils;

const isLight = (theme: FoundationTheme.Theme) => {
    const { palette = { primary: { main: '', contrastText: '' } } } = theme;
    return palette.primary.main === getAppColor(theme, 'primary', 'black');
};

export const DropdownContainer = styled.div<{ disabled: boolean }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
`;

export const DropdownHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${({ type, theme }) =>
        type === 'outlined' ? `1px solid ${getAppColor(theme, 'primary', 'black')}` : 'none'};
    color: ${({ theme }) => getPaletteColor(theme, 'primary')};
`;

export const DropdownButton = styled.div`
    padding-right: 10px;
`;

export const DropdownList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 100;
    border: 1px solid ${({ borderColor, theme }) => getPaletteColor(theme, borderColor)};
    padding: 0;
    margin: 0;
    width: 100%;
    color: ${({ theme }) => getPaletteColor(theme, 'primary')};
`;

export const ListItemContainer = styled.div<{ showListDivider: boolean }>`
    cursor: pointer;
    padding: 5px 0;
    border-bottom: 1px solid
        ${({ showListDivider, theme }) =>
        showListDivider
            ? isLight(theme)
                ? getAppColor(theme, 'neutral', '30')
                : getAppColor(theme, 'neutral', '20')
            : 'none'};
    &:hover {
        background-color: ${({ theme }) =>
        isLight(theme) ? getAppColor(theme, 'accentColorB', '10') : getAppColor(theme, 'accentColorB', '50')};
    }

    &:last-child {
        border-bottom: none;
    }
`;

export const ListItem = styled.span<{ isSelected: boolean }>`
    padding: 5px 10px;
    border-left: ${({ isSelected, theme }) =>
        isSelected ? `2px solid ${getPaletteColor(theme, 'primary')}` : 'none'};
`;
